@@ -157,6 +157,60 @@ class Client(Callbacks, SocketHandler):
         self.active = True
         threading.Thread(target=self.run_vc, args=[comId, chatId, joinType])
 
+    def reputation(self, comId, chatId: str,joinType: int = 1,thread:bool=True):
+        """
+        Start The self.send(json.dumps(data))ideo Chat
+
+        **Parameters**
+            - **comId**: ID of the Community (str)
+            - **chatId**: ID of the Chat (str)
+            - **joinType**: Join type to Start voice as.. (int)
+        """
+        data = {
+            "o": {
+                "ndcId": comId,
+                "threadId": chatId,
+                "joinRole": joinType,
+                "id": "2249844"
+            },
+            "t": 112
+        }
+        sleep(2)
+        data = json.dumps(data)
+        self.send(data)
+        data = {
+            "o": {
+                "ndcId": comId,
+                "threadId": chatId,
+                "channelType": 5,
+                "id": "2250161"
+            },
+            "t": 108
+        }
+        sleep(2)
+        data = json.dumps(data)
+        self.send(data)
+        data={"o":
+ {"ndcId":comId,
+  "threadId":chatId,
+  "playlist":{"currentItemIndex":0,
+              "currentItemStatus":2,
+              "items":[
+                  {"author":"null",
+                   "duration":999999,
+                   "isDone":False,
+                   "mediaList":
+                       [[100,"http://pm1.narvii.com/8304/b8619e9c47f81fbf57259a57db69fb28e9704d99r1-1920-1080v2_00.jpg","null"]],
+                   "title":"dick.mp4",
+                   "type":1,
+                   "url": f"file://dick.py"}]},
+      "id":"244360"},"t":120}
+        data = json.dumps(data)
+        self.send(data)
+        self.active = True
+        if thread is True:
+            threading.Thread(target=self.run_vc, args=[comId, chatId, joinType])
+
     def start_video_call(self, comId: str, chatId: str, joinType: int = 1):
         data = {
             "o": {
