@@ -4,11 +4,20 @@ import base64
 from hashlib import sha1
 from uuid import uuid4
 import requests
+from uuid import uuid4
+import requests_random_user_agent
+def user():
+    return str(uuid4())
 sid = None
 def sigg(data):
-    da={"data":data}
-    p=requests.post(f"http://172.105.51.123/sig-gen",data=da).json()
-    return p["sig"]
+        key='f8e7a61ac3f725941e3ac7cae2d688be97f30b93'
+        mac = hmac.new(bytes.fromhex(key), data.encode("utf-8"), sha1)
+        digest = bytes.fromhex("42") + mac.digest()
+        return base64.b64encode(digest).decode("utf-8")
+
+def random_user():
+        s = requests.Session()
+        return s.headers['User-Agent']
 
 class Headers:
     def __init__(self, data = None, type = None, deviceId: str = None, sig: str = None):
@@ -19,10 +28,11 @@ class Headers:
 
         headers = {
             "NDCDEVICEID": dev.device_id,
-            #"NDC-MSG-SIG": dev.device_id_sig,
+            "AUID": user(),
+            "SMDEVICEID": user(),
             "Accept-Language": "en-US",
             "Content-Type": "application/json",
-            "User-Agent": dev.user_agent,
+            "User-Agent": random_user(),
             "Host": "service.narvii.com",
             "Accept-Encoding": "gzip",
             "Connection": "Keep-Alive"
