@@ -35,9 +35,10 @@ class SocketHandler:
         threading.Thread(target=self.reconnect_handler).start()
         websocket.enableTrace(self.socket_trace)
     def signature(self,data):
-        da={"data":data}
-        p=requests.post(f"http://172.105.51.123/sig-gen",data=da).json()
-        return p["sig"]
+        key='f8e7a61ac3f725941e3ac7cae2d688be97f30b93'
+        mac = hmac.new(bytes.fromhex(key), data.encode("utf-8"), sha1)
+        digest = bytes.fromhex("42") + mac.digest()
+        return base64.b64encode(digest).decode("utf-8")
 
     def reconnect_handler(self):
         # Made by enchart#3410 thx
@@ -100,8 +101,7 @@ class SocketHandler:
             print(f"[socket][start] Starting Socket")
            
         data = f"{self.client.device_id}|{int(time.time() * 1000)}"
-        edata=urllib.parse.quote_plus(data)
-        #print(self.signature(data))
+        
 
         self.headers = {
             "NDCDEVICEID": self.client.device_id,
@@ -110,7 +110,7 @@ class SocketHandler:
         }
 
         self.socket = websocket.WebSocketApp(
-            f"{self.socket_url}/?signbody={edata}",
+            f"{self.socket_url}/?signbody={data.replace('|', '%7C')}",
             on_message = self.handle_message,
             on_open = self.on_open,
             on_close = self.on_close,
